TimeSource

Enum TimeSource 

#[repr(u8)]
pub enum TimeSource {
Show 17 variants None = 0, Unknown = 1, Admin = 2, Nodetimecluster = 3, Nonmattersntp = 4, Nonmatterntp = 5, Mattersntp = 6, Matterntp = 7, Mixedntp = 8, Nonmattersntpnts = 9, Nonmatterntpnts = 10, Mattersntpnts = 11, Matterntpnts = 12, Mixedntpnts = 13, Cloudsource = 14, Ptp = 15, Gnss = 16,
}

Variants



None = 0

Node is not currently synchronized with a UTC Time source.



Unknown = 1

Node uses an unlisted time source.



Admin = 2

Node received time from a client using the SetUTCTime Command.



Nodetimecluster = 3

Synchronized time by querying the Time Synchronization cluster of another Node.



Nonmattersntp = 4

SNTP from a server not in the Matter network. NTS is not used.



Nonmatterntp = 5

NTP from servers not in the Matter network. None of the servers used NTS.



Mattersntp = 6

SNTP from a server within the Matter network. NTS is not used.



Matterntp = 7

NTP from servers within the Matter network. None of the servers used NTS.



Mixedntp = 8

NTP from multiple servers in the Matter network and external. None of the servers used NTS.



Nonmattersntpnts = 9

SNTP from a server not in the Matter network. NTS is used.



Nonmatterntpnts = 10

NTP from servers not in the Matter network. NTS is used on at least one server.



Mattersntpnts = 11

SNTP from a server within the Matter network. NTS is used.



Matterntpnts = 12

NTP from a server within the Matter network. NTS is used on at least one server.



Mixedntpnts = 13

NTP from multiple servers in the Matter network and external. NTS is used on at least one server.



Cloudsource = 14

Time synchronization comes from a vendor cloud-based source (e.g. “Date” header in authenticated HTTPS connection).



Ptp = 15

Time synchronization comes from PTP.



Gnss = 16

Time synchronization comes from a GNSS source.

Implementations

Source

impl TimeSource

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value