#[repr(u8)]pub enum TimeZoneDatabase {
Full = 0,
Partial = 1,
None = 2,
}Variants
Full = 0
Node has a full list of the available time zones
Partial = 1
Node has a partial list of the available time zones
None = 2
Node does not have a time zone database
Implementations