Granularity

Enum Granularity 

#[repr(u8)]
pub enum Granularity { Notimegranularity = 0, Minutesgranularity = 1, Secondsgranularity = 2, Millisecondsgranularity = 3, Microsecondsgranularity = 4, }

Variants



Notimegranularity = 0

This indicates that the node is not currently synchronized with a UTC Time source and its clock is based on the Last Known Good UTC Time only.



Minutesgranularity = 1

This indicates the node was synchronized to an upstream source in the past, but sufficient clock drift has occurred such that the clock error is now > 5 seconds.



Secondsgranularity = 2

This indicates the node is synchronized to an upstream source using a low resolution protocol. UTC Time is accurate to ± 5 seconds.



Millisecondsgranularity = 3

This indicates the node is synchronized to an upstream source using high resolution time-synchronization protocol such as NTP, or has built-in GNSS with some amount of jitter applying its GNSS timestamp. UTC Time is accurate to ± 50 ms.



Microsecondsgranularity = 4

This indicates the node is synchronized to an upstream source using a highly precise time-synchronization protocol such as PTP, or has built-in GNSS. UTC time is accurate to ± 10 μs.

Implementations

Source

impl Granularity

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value